/******************************************************************************
 * 
 * Copyright 2012 - 2013 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/

package com.vektorsoft.demux.desktop.gui;

import com.vektorsoft.demux.core.mva.DMXEventRegistrationHandler;
import javafx.scene.control.Menu;
import javafx.scene.control.MenuItem;

/**
 * Service which defines methods for interacting with application menus.
 *
 * @author Vladimir Djurovic
 */
public interface JFXMenuService {

    /**
     * Appends specified menu at the end of menu bar.
     * 
     * @param menu menu to append
     */
    void appendToMenuBar(Menu menu);
    
    
    /**
     * Adds specified menu to menu bar after the menu with ID <code>menuId</code>. If menu with
     * ID matching <code>menuId</code>, menu will be appended to the end of menu bar. Also, if
     * {@code menuId} is <code>null</code>, menu will be appended to end of menu bar.
     * 
     * @param menuId menu ID
     * @param menu menu to add
     */
    void addAfterMenu(String menuId, Menu menu);
    
    /**
     * Insert specified menu at <code>index</code> position in menu bar. If {@code index} is not
     * a valid index, menu will be appended to the end of menu bar.
     * 
     * @param index index in menu bar where menu should be inserted
     * @param menu menu to insert
     */
    void insertAtIndex(int index, Menu menu);
    
    /**
     * Adds specified menu item to menu with specified ID.
     * 
     * @param menuId ID of menu to which item should be added
     * @param menuItem menu item to add
     */
    void addMenuItemToMenu(String menuId, MenuItem menuItem);
    
    /**
     * Insert specified menu item at position {@code index} within menu with ID {@code menuId}.
     * 
     * @param menuId menu ID
     * @param index index to insert to
     * @param item  menu item to insert
     */
    void insertMenuItem(String menuId, int index, MenuItem item);
    
    /**
     * Adds {@code subMenu} as a sub menu of menu with ID {@code menuId}.
     * 
     * @param menuId ID of parent menu
     * @param subMenu submenu
     */
    void addSubmenuToMenu(String menuId, Menu subMenu);
    
    /**
     * Insert separator at specified index in the menu.
     * 
     * @param menuId ID of menu in which to insert separator
     * @param index  separator position inside menu (zero-based)
     */
    void insertSeparator(String menuId, int index);
    
    /**
     * Registers controller to be invoked when menu item is fired.
     * 
     * @param menuItemId ID of menu item
     * @param controllerId controller ID
     * @param params optional parameters for controller execution
     */
    void registerControllerForAction(String menuItemId, String controllerId, Object... params);
    
    /**
     * Registers event handler for specified menu item.
     * 
     * @param menuItemId menu item ID
     * @param handler event handler
     
     */
    void registerEventHandlerForMenuItem(String menuItemId, DMXEventRegistrationHandler handler);
}
